#!/usr/bin/env python
# encoding: utf-8

"""
Evaluation reports
"""

from repytex.tools import (
    extract_flat_marks,
    get_class_ws,
    digest_flat_df,
    evaluation
    )
import pandas as pd
from path import Path
from .produce_compile import produce_compile

import logging
logger = logging.getLogger(__name__)


def eval_info(classe, ds_df):
    """TODO: Docstring for build_ds_info.

    :param ds_df: TODO
    :returns: TODO


    # TODO: vérifier que toutes ces informations soient identiques sur les lignes |dim. nov.  6 16:06:58 EAT 2016
    """
    eval_info = {}
    eval_info["Classe"] = classe
    eval_info["Nom"] = ds_df["Nom"].unique()[0]
    eval_info["Date"] = pd.to_datetime(ds_df["Date"].unique()[0]).strftime("%d-%m-%Y")
    eval_info["Trimestre"] = ds_df["Trimestre"].unique()[0]
    return eval_info


def build_target_name(classe, evalname, path = Path("./")):
    """ Build the path where the .tex will be sored

    >>> build_target_name("312", "DS1")
    Path('./312/report_DS1.tex')
    >>> build_target_name("312", "DS1", Path("plop/"))
    Path('plop/312/report_DS1.tex')
    """
    return Path(path + "/" + classe + "/report_" + evalname + ".tex")


def eval_report(classe, evalname, path = Path('./'),
        template="tpl_reports_eval.tex", force=1):
    """ Generate the report of a evaluation for a class

    :param classe: the classe name
    :param evalname: name of the evaluation
    :param path: path where xlsx are stored
    :param template: template for the report
    :param force: Override existing documents

    """
    ws = get_class_ws(classe, path)
    logger.info("Worksheets of {} imported".format(classe))

    flat_df = extract_flat_marks(ws)
    logger.info("Worksheets parsed")

    this_df = flat_df[flat_df['Nom'] == evalname]
    quest_df, exo_df, eval_df = digest_flat_df(this_df)

    report_info = eval_info(classe, eval_df)

    students = evaluation.students_pov(quest_df, exo_df, eval_df)
    class_pov = evaluation.class_pov(quest_df, exo_df, eval_df)

    studs = {*this_df['Eleve']}
    present = {*eval_df['Eleve']}
    absents = studs - present

    datas = {"report_info": report_info,
            "students":students,
            "classe": class_pov,
            "absents": absents
            }

    target = build_target_name(classe, evalname, path)
    produce_compile(template, datas, target, force)


# -----------------------------
# Reglages pour 'vim'
# vim:set autoindent expandtab tabstop=4 shiftwidth=4:
# cursor: 16 del
